%DECODIFICADOR DE LOS TÉRMINOS LTP.
%function[Np,bp]=ltpdec(Nc,bc)
%Entradas:
%Nc:término de autocorrelación codificado.
%bc:ganancia de autocorrelación codificado.
%Salidas:
%Np:término de autocorrelación decodificado.
%bp:ganancia de autocorrelación decodificado.
function[Np,bp]=ltpdec(Nc,bc)
Np=Nc;
QLB=[0.10 0.35 0.65 1.00];
bp=QLB(bc+1);

